@@ -919,8 +919,17 @@ class cGelbeListeWindowsInterface(cDrugDataSourceInterface):
 					'data': self.__data_date,
 					'online_update': self.__online_update_date
 				}
-
-		open(self.data_date_filename, 'wb').close()
+		try:
+			open(self.data_date_filename, 'wb').close()
+		except StandardError:
+			_log.error('problem querying the MMI drug database for version information')
+			_log.exception('cannot create MMI drug database version file [%s]', self.data_date_filename)
+			self.__data_date = None
+			self.__online_update_date = None
+			return {
+				'data': u'?',
+				'online_update': u'?'
+			}
 
 		cmd = u'%s -DATADATE' % self.path_to_binary
 		if not gmShellAPI.run_command_in_shell(command = cmd, blocking = True):
@@ -1578,11 +1587,15 @@ class cSubstanceIntakeEntry(gmBusinessDBObject.cBusinessDBObject):
 		allg['atc_code'] = gmTools.coalesce(self._payload[self._idx['atc_substance']], self._payload[self._idx['atc_brand']])
 		if self._payload[self._idx['external_code_brand']] is not None:
 			allg['substance_code'] = u'%s::::%s' % (self._payload[self._idx['external_code_type_brand']], self._payload[self._idx['external_code_brand']])
-		comps = [ c['substance'] for c in self.containing_drug.components ]
-		if len(comps) == 0:
+
+		if self._payload[self._idx['pk_brand']] is None:
 			allg['generics'] = self._payload[self._idx['substance']]
 		else:
-			allg['generics'] = u'; '.join(comps)
+			comps = [ c['substance'] for c in self.containing_drug.components ]
+			if len(comps) == 0:
+				allg['generics'] = self._payload[self._idx['substance']]
+			else:
+				allg['generics'] = u'; '.join(comps)
 
 		allg.save()
 		return allg
