@@ -173,6 +173,85 @@ class cBusinessDBObject(object):
 	<_updatable_fields>
 		- a list of fields available for update via object['field']
 
+
+	A template for new child classes:
+
+#------------------------------------------------------------
+from Gnumed.pycommon import gmBusinessDBObject
+from Gnumed.pycommon import gmPG2
+
+#============================================================
+# description
+#------------------------------------------------------------
+_SQL_get_XXX = u\"""
+	SELECT *, (xmin AS xmin_XXX)
+	FROM XXX.v_XXX
+	WHERE %s
+\"""
+
+class cXxxXxx(gmBusinessDBObject.cBusinessDBObject):
+
+	_cmd_fetch_payload = _SQL_get_XXX % u"pk_XXX = %s"
+	_cmds_store_payload = [
+		u\"""
+			UPDATE xxx.xxx SET								-- typically the underlying table name
+				xxx = %(xxx)s,								-- typically "table_col = %(view_col)s"
+				xxx = gm.nullify_empty_string(%(xxx)s)
+			WHERE
+				pk = %(xxx)s
+					AND
+				xmin = %(xmin_XXX)s
+			RETURNING
+				pk as pk_XXX,
+				xmin as xmin_XXX
+		\"""
+	]
+	# view columns:
+	_updatable_fields = [
+		u'xxx',
+		u'xxx'
+	]
+#------------------------------------------------------------
+def get_XXX(order_by=None):
+	if order_by is None:
+		order_by = u'true'
+	else:
+		order_by = u'true ORDER BY %s' % order_by
+
+	cmd = _SQL_get_XXX % order_by
+	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd}], get_col_idx = True)
+	return [ cXxxXxx(row = {'data': r, 'idx': idx, 'pk_field': 'xxx'}) for r in rows ]
+#------------------------------------------------------------
+def create_xxx(xxx=None, xxx=None):
+
+	args = {
+		u'xxx': xxx,
+		u'xxx': xxx
+	}
+	cmd = u\"""
+		INSERT INTO xxx.xxx (
+			xxx,
+			xxx,
+			xxx
+		) VALUES (
+			%(xxx)s,
+			%(xxx)s,
+			gm.nullify_empty_string(%(xxx)s)
+		)
+		RETURNING pk
+	\"""
+	rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], return_data = True, get_col_idx = False)
+
+	return cXxxXxx(aPK_obj = rows[0]['pk'])
+#------------------------------------------------------------
+def delete_xxx(xxx=None):
+	args = {'pk': xxx}
+	cmd = u"DELETE FROM xxx.xxx WHERE pk = %(pk)s"
+	gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
+	return True
+#------------------------------------------------------------
+
+
 	"""
 	#--------------------------------------------------------
 	def __init__(self, aPK_obj=None, row=None):
@@ -428,6 +507,13 @@ class cBusinessDBObject(object):
 			get_col_idx = True
 		)
 
+		# this can happen if:
+		# - someone else updated the row so XMIN does not match anymore
+		# - the PK went away (rows was deleted from under us)
+		# - another WHERE condition of the UPDATE did not produce any rows to update
+		if len(rows) == 0:
+			return (False, (u'cannot update row', _('[%s:%s]: row not updated (nothing returned), row in use ?') % (self.__class__.__name__, self.pk_obj)))
+
 		# update cached XMIN values (should be in first-and-only result row of last query)
 		row = rows[0]
 		for key in idx:
@@ -478,6 +564,16 @@ def jsonclasshintify(obj):
 		res['seconds'] = obj.seconds
 		res['microseconds'] = obj.microseconds
 		return res
+	elif isinstance(obj, datetime.time):
+		# this will get decoded as "from jsonobjproxy import {clsname}"
+		# at the remote (client) end.
+		res = {'__jsonclass__': ["jsonobjproxy.Time"]}
+		res['hour'] = obj.hour
+		res['minute'] = obj.minute
+		res['second'] = obj.second
+		res['microsecond'] = obj.microsecond
+		res['tzinfo'] = jsonclasshintify(obj.tzinfo)
+		return res
 	elif isinstance(obj, datetime.datetime):
 		# this will get decoded as "from jsonobjproxy import {clsname}"
 		# at the remote (client) end.
@@ -496,9 +592,21 @@ def jsonclasshintify(obj):
 		# at the remote (client) end.
 		res = {'__jsonclass__': ["jsonobjproxy.%s" % obj.__class__.__name__]}
 		for k in obj.get_fields():
-			res[k] = jsonclasshintify(obj[k])
+			t = jsonclasshintify(obj[k])
+			res[k] = t
+		print "props", res, dir(obj)
+		for attribute in dir(obj):
+			if not attribute.startswith("get_"):
+				continue
+			k = attribute[4:]
+			if res.has_key(k):
+				continue
+			getter = getattr(obj, attribute, None)
+			if callable(getter):
+				res[k] = jsonclasshintify(getter())
 		return res
 	return obj
+
 #============================================================
 if __name__ == '__main__':
 
@@ -535,4 +643,3 @@ if __name__ == '__main__':
 	obj['wrong_field'] = 1
 
 #============================================================
-
