@@ -235,6 +235,14 @@ def mxdt2py_dt(mxDateTime):
 		)
 		raise
 #===========================================================================
+def format_dob(dob, format='%x', encoding=None, none_string=None):
+	if dob is None:
+		if none_string is None:
+			return _('** DOB unknown **')
+		return none_string
+
+	return pydt_strftime(dob, format = format, encoding = encoding, accuracy = acc_days)
+#---------------------------------------------------------------------------
 def pydt_strftime(dt, format='%c', encoding=None, accuracy=None):
 
 	if encoding is None:
@@ -988,16 +996,16 @@ def __numbers_only2py_dt(str2parse):
 		})
 
 	# day X of next month
-	ts = now + mxDT.RelativeDateTime(months = 1, day = val)
-	if (val > 0) and (val <= gregorian_month_length[ts.month]):
+	if (val > 0) and (val < 32):
+		ts = now + mxDT.RelativeDateTime(months = 1, day = val)
 		matches.append ({
 			'data': mxdt2py_dt(ts),
 			'label': _('%d. of %s (next month): a %s') % (val, ts.strftime('%B').decode(enc), ts.strftime('%A').decode(enc))
 		})
 
 	# day X of last month
-	ts = now + mxDT.RelativeDateTime(months = -1, day = val)
-	if (val > 0) and (val <= gregorian_month_length[ts.month]):
+	if (val > 0) and (val < 32):
+		ts = now + mxDT.RelativeDateTime(months = -1, day = val)
 		matches.append ({
 			'data': mxdt2py_dt(ts),
 			'label': _('%d. of %s (last month): a %s') % (val, ts.strftime('%B').decode(enc), ts.strftime('%A').decode(enc))
@@ -1239,12 +1247,11 @@ def str2pydt_matches(str2parse=None, patterns=None):
 			text = str2parse,
 			formats = ('euro', 'iso', 'us', 'altus', 'altiso', 'lit', 'altlit', 'eurlit')
 		)
-		# FIXME: convert to python datetime
 		matches.append ({
 			'data': mxdt2py_dt(date),
 			'label': date.strftime('%Y-%m-%d')
 		})
-	except (ValueError, mxDT.RangeError):
+	except (ValueError, OverflowError, mxDT.RangeError):
 		pass
 
 	# apply explicit patterns
@@ -1254,10 +1261,16 @@ def str2pydt_matches(str2parse=None, patterns=None):
 	patterns.append('%Y.%m.%d')
 	patterns.append('%Y/%m/%d')
 	patterns.append('%Y-%m-%d')
+	patterns.append('%d/%m/%Y')
 
 	for pattern in patterns:
 		try:
-			date = pyDT.datetime.strptime(str2parse, pattern)
+			date = pyDT.datetime.strptime(str2parse, pattern).replace (
+				hour = 11,
+				minute = 11,
+				second = 11,
+				tzinfo = gmCurrentLocalTimezone
+			)
 			matches.append ({
 				'data': mxdt2py_dt(date),
 				'label': date.strftime('%Y-%m-%d')
