@@ -1114,7 +1114,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 	def __init__(self, parent, id, *args, **kwds):
 		"""Set up our specialised tree.
 		"""
-		kwds['style'] = wx.TR_NO_BUTTONS | wx.NO_BORDER
+		kwds['style'] = wx.TR_NO_BUTTONS | wx.NO_BORDER | wx.TR_SINGLE
 		wx.TreeCtrl.__init__(self, parent, id, *args, **kwds)
 
 		gmRegetMixin.cRegetOnPaintMixin.__init__(self)
@@ -1799,7 +1799,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 			parent = self,
 			patient = gmPerson.gmCurrentPatient()
 		)
-		if enc is None:
+		if not enc:
 			return
 		self.__curr_node_data['pk_encounter'] = enc['pk_encounter']
 		self.__curr_node_data.save()
