@@ -57,15 +57,31 @@ class cXxxEAPnl(wxgXxxEAPnl.wxgXxxEAPnl, gmEditArea.cGenericEditAreaMixin):
 	# generic Edit Area mixin API
 	#----------------------------------------------------------------
 	def _valid_for_save(self):
+		# remove when implemented:
 		return False
-		return True
+
+		validity = True
+
+		if self._TCTRL_xxx.GetValue().strip() == u'':
+			validity = False
+			self.display_tctrl_as_valid(tctrl = self._TCTRL_xxx, valid = False)
+		else:
+			self.display_tctrl_as_valid(tctrl = self._TCTRL_xxx, valid = True)
+
+		if self._PRW_xxx.GetData() is None:
+			validity = False
+			self._PRW_xxx.display_as_valid(False)
+		else:
+			self._PRW_xxx.display_as_valid(True)
+
+		return validity
 	#----------------------------------------------------------------
 	def _save_as_new(self):
 		# save the data as a new instance
-		data = 
+		data = gmXXXX.create_xxxx()
 
-		data[''] = 
-		data[''] = 
+		data[''] = self._
+		data[''] = self._
 
 		data.save()
 
@@ -78,19 +94,19 @@ class cXxxEAPnl(wxgXxxEAPnl.wxgXxxEAPnl, gmEditArea.cGenericEditAreaMixin):
 	#----------------------------------------------------------------
 	def _save_as_update(self):
 		# update self.data and save the changes
-		self.data[''] = 
-		self.data[''] = 
-		self.data[''] = 
+		self.data[''] = self._TCTRL_xxx.GetValue().strip()
+		self.data[''] = self._PRW_xxx.GetData()
+		self.data[''] = self._CHBOX_xxx.GetValue()
 		self.data.save()
 		return True
 	#----------------------------------------------------------------
 	def _refresh_as_new(self):
 		pass
 	#----------------------------------------------------------------
-	def _refresh_from_existing(self):
-		pass
-	#----------------------------------------------------------------
 	def _refresh_as_new_from_existing(self):
+		self._refresh_as_new()
+	#----------------------------------------------------------------
+	def _refresh_from_existing(self):
 		pass
 	#----------------------------------------------------------------
 	"""
@@ -163,23 +179,34 @@ class cXxxEAPnl(wxgXxxEAPnl.wxgXxxEAPnl, gmEditArea.cGenericEditAreaMixin):
 		"""Invoked from the generic edit area dialog.
 
 		Invokes
-			_refresh_as_new
-			_refresh_from_existing
-			_refresh_as_new_from_existing
+			_refresh_as_new()
+			_refresh_from_existing()
+			_refresh_as_new_from_existing()
 		on the implementing edit area as needed.
+
+		Then calls _valid_for_save().
 		"""
 		if self.__mode == 'new':
-			return self._refresh_as_new()
+			result = self._refresh_as_new()
+			self._valid_for_save()
+			return result
 		elif self.__mode == 'edit':
-			return self._refresh_from_existing()
+			result = self._refresh_from_existing()
+			return result
 		elif self.__mode == 'new_from_existing':
-			return self._refresh_as_new_from_existing()
+			result = self._refresh_as_new_from_existing()
+			self._valid_for_save()
+			return result
 		else:
 			raise ValueError('[%s] <mode> must be in %s' % (self.__class__.__name__, edit_area_modes))
 	#----------------------------------------------------------------
 	def display_tctrl_as_valid(self, tctrl=None, valid=None):
 		tctrl.SetBackgroundColour(self.__tctrl_validity_colors[valid])
 		tctrl.Refresh()
+	#----------------------------------------------------------------
+	def display_ctrl_as_valid(self, ctrl=None, valid=None):
+		ctrl.SetBackgroundColour(self.__tctrl_validity_colors[valid])
+		ctrl.Refresh()
 #====================================================================
 class cGenericEditAreaDlg2(wxgGenericEditAreaDlg2.wxgGenericEditAreaDlg2):
 	"""Dialog for parenting edit area panels with save/clear/next/cancel"""
@@ -204,6 +231,8 @@ class cGenericEditAreaDlg2(wxgGenericEditAreaDlg2.wxgGenericEditAreaDlg2):
 
 		wxgGenericEditAreaDlg2.wxgGenericEditAreaDlg2.__init__(self, *args, **kwargs)
 
+		self.left_extra_button = None
+
 		if cGenericEditAreaDlg2._today.day != cGenericEditAreaDlg2._lucky_day:
 			self._BTN_lucky.Enable(False)
 			self._BTN_lucky.Hide()
@@ -213,15 +242,18 @@ class cGenericEditAreaDlg2(wxgGenericEditAreaDlg2.wxgGenericEditAreaDlg2):
 				self._BTN_lucky.Hide()
 
 		# replace dummy panel
-		old_ea = self._PNL_ea
-		ea_pnl_szr = old_ea.GetContainingSizer()
-		ea_pnl_parent = old_ea.GetParent()
-		ea_pnl_szr.Remove(old_ea)
-		old_ea.Destroy()
-		del old_ea
+		dummy_ea_pnl = self._PNL_ea
+		ea_pnl_szr = dummy_ea_pnl.GetContainingSizer()
+		ea_pnl_parent = dummy_ea_pnl.GetParent()
+		ea_pnl_szr.Remove(dummy_ea_pnl)
+		dummy_ea_pnl.Destroy()
+		del dummy_ea_pnl
+		new_ea_min_size = new_ea.GetMinSize()
 		new_ea.Reparent(ea_pnl_parent)
 		self._PNL_ea = new_ea
 		ea_pnl_szr.Add(self._PNL_ea, 1, wx.EXPAND, 0)
+		ea_pnl_szr.SetMinSize(new_ea_min_size)					# set minimum size of EA pnl sizer from its new EA item
+		ea_pnl_szr.Fit(new_ea)									# resize the new EA to the minimum size of the EA pnl sizer
 
 		# adjust buttons
 		if single_entry:
@@ -231,10 +263,11 @@ class cGenericEditAreaDlg2(wxgGenericEditAreaDlg2.wxgGenericEditAreaDlg2):
 		self._adjust_clear_revert_buttons()
 
 		# redraw layout
-		self.Layout()
+		#self.Layout()
 		main_szr = self.GetSizer()
 		main_szr.Fit(self)
-		self.Refresh()
+		self.Layout()
+		#self.Refresh()				# apparently not needed (27.3.2011)
 
 		self._PNL_ea.refresh()
 	#--------------------------------------------------------
@@ -287,6 +320,35 @@ class cGenericEditAreaDlg2(wxgGenericEditAreaDlg2.wxgGenericEditAreaDlg2):
 			),
 			_('GNUmed Lottery')
 		)
+	#--------------------------------------------------------
+	def _on_left_extra_button_pressed(self, event):
+		if not self.__left_extra_button_callback(self._PNL_ea.data):
+			return
+
+		if self.IsModal():
+			self.EndModal(wx.ID_OK)
+		else:
+			self.Close()
+	#------------------------------------------------------------
+	# properties
+	#------------------------------------------------------------
+	def _set_left_extra_button(self, definition):
+		if definition is None:
+			self._BTN_extra_left.Enable(False)
+			self._BTN_extra_left.Hide()
+			self.__left_extra_button_callback = None
+			return
+
+		(label, tooltip, callback) = definition
+		if not callable(callback):
+			raise ValueError('<left extra button> callback is not a callable: %s' % callback)
+		self.__left_extra_button_callback = callback
+		self._BTN_extra_left.SetLabel(label)
+		self._BTN_extra_left.SetToolTipString(tooltip)
+		self._BTN_extra_left.Enable(True)
+		self._BTN_extra_left.Show()
+
+	left_extra_button = property(lambda x:x, _set_left_extra_button)
 #====================================================================
 # DEPRECATED:
 class cGenericEditAreaDlg(wxgGenericEditAreaDlg.wxgGenericEditAreaDlg):
@@ -325,11 +387,11 @@ class cGenericEditAreaDlg(wxgGenericEditAreaDlg.wxgGenericEditAreaDlg):
 #====================================================================
 #====================================================================
 #====================================================================
-import time
+#import time
 
-from Gnumed.business import gmPerson, gmDemographicRecord
+#from Gnumed.business import gmPerson, gmDemographicRecord
 from Gnumed.pycommon import gmGuiBroker
-from Gnumed.wxpython import gmDateTimeInput, gmPhraseWheel, gmGuiHelpers
+#from Gnumed.wxpython import gmDateTimeInput, gmPhraseWheel, gmGuiHelpers
 
 _gb = gmGuiBroker.GuiBroker()
 
@@ -1458,10 +1520,11 @@ class gmPastHistoryEditArea(gmEditArea):
 		try:
 			birthyear = int(str(self._patient['dob']).split('-')[0]) 
 		except:
-			birthyear = time.localtime()[0]
-		
+#			birthyear = time.localtime()[0]
+			birthyear = 1
+
 		return birthyear
-		
+
 	def _yearKillFocus( self, event):	
 		event.Skip()	
 		try:
@@ -1475,7 +1538,7 @@ class gmPastHistoryEditArea(gmEditArea):
 			"notes1": "",
 			"notes2": "",
 			"age": "",
-			"year": str(time.localtime()[0]),
+			#"year": str(time.localtime()[0]),
 			"progress": "",
 			"active": 1,
 			"operation": 0,
@@ -1489,7 +1552,8 @@ class gmPastHistoryEditArea(gmEditArea):
 
 	def _getDefaultAge(self):
 		try:
-			return	time.localtime()[0] - self._patient.getBirthYear()
+			#return	time.localtime()[0] - self._patient.getBirthYear()
+			return 1
 		except:
 			return 0
 
@@ -1497,8 +1561,7 @@ class gmPastHistoryEditArea(gmEditArea):
 		values = gmPastHistoryEditArea.__init_values
 		values["age"] = str( self._getDefaultAge())
 		return values 
-		
-		
+
 	def _save_data(self):
 		clinical = self._patient.get_emr().get_past_history()
 		if self.getDataId() is None:
