@@ -66,6 +66,12 @@ def move_progress_notes_to_another_encounter(parent=None, encounters=None, episo
 			single_selection = False,
 			encounters = encs
 		)
+		# cancelled
+		if encounters is None:
+			return True
+		# none selected
+		if len(encounters) == 0:
+			return True
 
 	notes = emr.get_clin_narrative (
 		encounters = encounters,
@@ -1204,12 +1210,15 @@ class cSoapPluginPnl(wxgSoapPluginPnl.wxgSoapPluginPnl, gmRegetMixin.cRegetOnPai
 		event.Skip()
 	#--------------------------------------------------------
 	def _on_save_note_under_button_pressed(self, event):
-		encounter = gmEMRStructWidgets.select_encounters (
+		encounters = gmEMRStructWidgets.select_encounters (
 			parent = self,
 			patient = self.__pat,
 			single_selection = True
 		)
-		if encounter is None:
+		# cancelled:
+		if encounters is None:
+			return
+		if len(encounters) == 0:
 			return
 
 		emr = self.__pat.get_emr()
@@ -1432,7 +1441,7 @@ class cSoapNoteInputNotebook(wx.Notebook):
 		_log.debug('saving editors: %s', self.GetPageCount())
 
 		all_closed = True
-		for page_idx in range((self.GetPageCount() - 1), 0, -1):
+		for page_idx in range((self.GetPageCount() - 1), -1, -1):
 			_log.debug('#%s of %s', page_idx, self.GetPageCount())
 			try:
 				self.ChangeSelection(page_idx)
@@ -1668,7 +1677,8 @@ class cSoapNoteExpandoEditAreaPnl(wxgSoapNoteExpandoEditAreaPnl.wxgSoapNoteExpan
 		# need to tell ourselves to re-Layout to refresh scroll bars
 
 		# provoke adding scrollbar if needed
-		self.Fit()
+		#self.Fit()
+		self.FitInside()		# needed on Windows rather than self.Fit()
 
 		if self.HasScrollbar(wx.VERTICAL):
 			# scroll panel to show cursor
